OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Учитавам преглед…",
    "Admin" : "Администрација",
    "Saved" : "Сачувано",
    "a safe home for all your data" : "сигурно место за све ваше податке",
    "Name cannot be empty" : "Назив не може бити празан",
    "The given name is too long" : "Назив је предугачак",
    "The given web address is too long" : "Наведена веб адреса је предугачка",
    "The given web address is not a valid URL" : "Наведена веб адреса није исправан УРЛ",
    "The given legal notice address is too long" : "Адреса правног обавештења је предугачка",
    "The given legal notice address is not a valid URL" : "Адреса правног обавештења није исправан УРЛ",
    "The given privacy policy address is too long" : "Адреса смерница приватности је предугачка",
    "The given privacy policy address is not a valid URL" : "Адреса смерница приватности није исправан УРЛ",
    "The given slogan is too long" : "Слоган је предугачак",
    "The given color is invalid" : "Задата боја није исправна",
    "The file was uploaded" : "Фајл је отпремљен",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Отпремани фајл превазилази смерницу upload_max_filesize у фајлу php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Отпремани фајл превазилази смерницу MAX_FILE_SIZE наведену у ХТМЛ обрасцу",
    "The file was only partially uploaded" : "Фајл је само делимично отпремљен",
    "No file was uploaded" : "Није отпремљен фајл",
    "Missing a temporary folder" : "Недостаје привремена фасцикла",
    "Could not write file to disk" : "Не могу да упишем фајл на диск",
    "A PHP extension stopped the file upload" : "ПХП екстензија је зауставила отпремање фајла",
    "No file uploaded" : "Није отпремљен фајл",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Већ користите прилагођену тему. Поставке ове апликације ће прегажене са њом.",
    "Theming" : "Изглед",
    "Dark theme" : "Тамна тема",
    "Enable dark theme" : "укључи тамну тему",
    "Dyslexia font" : "Фонт Дислексија",
    "Enable dyslexia font" : "укључи фонт Дислексија",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "„OpenDyslexic“ је бесплатни фонт дизајниран да умањи честе грешке у читању изазване дислексијом.",
    "High contrast mode" : "Режим високог контраста",
    "Enable high contrast mode" : "укључи режим високог контраста",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Режим високог контраста за лакшу навигацију. Визуелни доживљај биће лошији али ће јасноћа бити боља.",
    "Legal notice" : "Правно обавештење",
    "Privacy policy" : "Смернице приватности",
    "Adjust the Nextcloud theme" : "Прилагоди Некстклауд тему",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Универзални приступ нам је веома важан. Пратимо веб стандарде и проверавамо да све буде употребљиво и без миша а и са помоћним софтвером попут читача екрана. Циљ нам је да будемо усклађени са документом {guidelines}Смернице приступачности веб садржаја{linkend}  2.1 на АА нивоу а са темом високог контраста и на ААА нивоу.",
    "Open documentation" : "Отвори документацију",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Омогућава да лако измените изглед и угођај вашег Некстклауда. Ово ће бити видљиво свим корисницима.",
    "Name" : "Назив",
    "Reset to default" : "Врати на подразумевано",
    "Web link" : "Веб веза",
    "https://…" : "https://…",
    "Slogan" : "Слоган",
    "Color" : "Боја",
    "Logo" : "Лого",
    "Upload new logo" : "Отпремите нови лого",
    "Login image" : "Пријавна слика",
    "Upload new login background" : "Отпремите нову позадину за пријавни екран",
    "Remove background image" : "Уклони позадинску слику",
    "Advanced options" : "Напредне опције",
    "Legal notice link" : "Правно обавештење",
    "Privacy policy link" : "Смернице приватности",
    "Header logo" : "Лого заглавља",
    "Upload new header logo" : "Отпремите нови лого заглавља",
    "Favicon" : "Икона веб стране",
    "Upload new favicon" : "Отпремите нову иконицу",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Инсталирајте „Imagemagick“ ПХП екстензију са подршком за СВГ слике, да аутоматски направи иконе од отпремљеног логоа и боје."
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
